cheesecake.model.System

Package cheesecake :: Module model :: Class System |
[show private | hide private]
[frames | no frames]

## Type System

    object --+
             |
            System

Method Summary
| `__init__(self)`
| `__getstate__(self)`
| `__setstate__(self, state)`
| `finalStateComputations(self)`
| ``handleDuplicate`(self, obj)` This is called when we see two objects with the same .fullName(), for example:
| `objectsOfType(self, cls)`
| `pop(self, obj)`
| `popClass(self)`
| `popFunction(self)`
| `popModule(self)`
| `popPackage(self)`
| `push(self, obj, node)`
| `pushClass(self, name, docstring)`
| `pushFunction(self, name, docstring, func_called)`
| `pushModule(self, name, docstring)`
| `pushPackage(self, name, docstring)`
| `recordBasesAndSubclasses(self)`
| `report(self)`
| `resolveAlias(self, n)`
| `resolveAliases(self)`
| `warning(self, type, detail)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Class Variable Summary
`type` | `Class` = `cheesecake.model.Class`
`type` | `Function` = `cheesecake.model.Function`
`type` | `Module` = `cheesecake.model.Module`
`type` | `ModuleVistor` = `cheesecake.model.ModuleVistor`
`type` | `Package` = `cheesecake.model.Package`

Method Details

### handleDuplicate(self, obj) This is called when we see two objects with the same .fullName(), for example: class C: if something: def meth(self): implementation 1 else: def meth(self): implementation 2 The default is that the second definition "wins".

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net